==> siag_3.0.6.orig.tar.gz: siag-3.0.6/siag/keytable.scm <==
(add-keybinding "SPC" "(set-block)")
(add-keybinding "C-@" "(set-mark-command)")
(add-keybinding "ESC SPC" "(unset-block)")
(add-keybinding "C-a" "(beginning-of-line)")
(add-keybinding "C-b" "(backward-cell)")
(add-keybinding "C-d" "(delete-cell)")
(add-keybinding "C-e" "(end-of-line)")
(add-keybinding "C-f" "(forward-cell)")
(add-keybinding "C-g" "(keyboard-quit)")
(add-keybinding "C-l" "(recenter)")
(add-keybinding "C-n" "(next-line)")
(add-keybinding "C-o" "(insert-line)")
(add-keybinding "C-p" "(previous-line)")
(add-keybinding "C-r" "(search-backward)")
(add-keybinding "C-s" "(search-forward)")
(add-keybinding "C-u" "(universal-argument)")
(add-keybinding "C-v" "(scroll-up)")
(add-keybinding "M-v" "(scroll-down)")
(add-keybinding "ESC v" "(scroll-down)")
(add-keybinding "M-x" "(execute-extended-command)")
(add-keybinding "ESC x" "(execute-extended-command)")
(add-keybinding "C-z" "(invoke-shell)")
(add-keybinding "?" "(what-cursor-position)")
(add-keybinding "C-x ?" "(what-cursor-position)")
(add-keybinding "!" "(recalc-matrix)")
(add-keybinding "=" "(edit-expression)")
(add-keybinding "\"" "(edit-label)")
(add-keybinding "(" "(execute-extended-command)")
(add-keybinding "<" "(beginning-of-buffer)")
(add-keybinding "M-<" "(beginning-of-buffer)")
(add-keybinding "ESC <" "(beginning-of-buffer)")
(add-keybinding ">" "(end-of-buffer)")
(add-keybinding "M->" "(end-of-buffer)")
(add-keybinding "ESC >" "(end-of-buffer)")
(add-keybinding "ESC" "(prefix)")
(add-keybinding "ESC C-g" "(keyboard-quit)")
(add-keybinding "ESC b" "(scroll-right)")
(add-keybinding "ESC f" "(scroll-left)")
(add-keybinding "ESC g" "(go-to)")
(add-keybinding "ESC p" "(top-of-buffer)")
(add-keybinding "ESC n" "(bottom-of-buffer)")
(add-keybinding "ESC -" "(argument-sign)")
(add-keybinding "ESC 0" "(argument-digit)")
(add-keybinding "ESC 1" "(argument-digit)")
(add-keybinding "ESC 2" "(argument-digit)")
(add-keybinding "ESC 3" "(argument-digit)")
(add-keybinding "ESC 4" "(argument-digit)")
(add-keybinding "ESC 5" "(argument-digit)")
(add-keybinding "ESC 6" "(argument-digit)")
(add-keybinding "ESC 7" "(argument-digit)")
(add-keybinding "ESC 8" "(argument-digit)")
(add-keybinding "ESC 9" "(argument-digit)")
(add-keybinding "C-x" "(prefix)")
(add-keybinding "C-x C-b" "(list-buffers)")
(add-keybinding "C-x C-c" "(quit-siag)")
(add-keybinding "C-x C-f" "(load-buffer)")
(add-keybinding "C-x C-g" "(keyboard-quit)")
(add-keybinding "C-x C-s" "(save-buffer)")
(add-keybinding "C-x C-w" "(save-buffer-as)")
(add-keybinding "C-x C-x" "(exchange-point-and-mark)")
(add-keybinding "C-x b" "(switch-to-buffer)")
(add-keybinding "C-x e" "(call-last-kbd-macro)")
(add-keybinding "C-x k" "(kill-buffer)")
(add-keybinding "C-x o" "(other-window)")
(add-keybinding "C-x 0" "(delete-window)")
(add-keybinding "C-x 1" "(delete-other-windows)")
(add-keybinding "C-x 2" "(split-window-vertically)")
(add-keybinding "C-x =" "(what-cursor-position)")
(add-keybinding "C-x (" "(start-kbd-macro)")
(add-keybinding "C-x )" "(end-kbd-macro)")
(add-keybinding "C-c" "(prefix)")
(add-keybinding "C-c C-d" "(delete-cell)")
(add-keybinding "C-c C-g" "(keyboard-quit)")
(add-keybinding "C-c !" "(recalc-matrix)")
(add-keybinding "C-c g" "(go-to)")
(add-keybinding "C-c l" "(edit-label)")
(add-keybinding "C-c x" "(edit-expression)")
(add-keybinding "C-c =" "(interpreter-test 'C)")
(add-keybinding "C-c b" "(prefix)")
(add-keybinding "C-c b ?" "(llpr \"One of SPC c d i p s\")")
(add-keybinding "C-c b C-g" "(keyboard-quit)")
(add-keybinding "C-c b SPC" "(set-block)")
(add-keybinding "C-c b c" "(copy-block)")
(add-keybinding "C-c b d" "(delete-block)")
(add-keybinding "C-c b f" "(fill-block)")
(add-keybinding "C-c b i" "(intelligent-copy-block)")
(add-keybinding "C-c b p" "(print-block)")
(add-keybinding "C-c b s" "(save-block-file)")
(add-keybinding "C-c c" "(prefix)")
(add-keybinding "C-c c C-g" "(keyboard-quit)")
(add-keybinding "C-c c ?" "(llpr \"One of g s t\")")
(add-keybinding "C-c c g" "(execute-guile)")
(add-keybinding "C-c c s" "(execute-siod)")
(add-keybinding "C-c c t" "(execute-tcl)")
(add-keybinding "C-c s" "(prefix)")
(add-keybinding "C-c s ?" "(llpr \"One of l r c w h\")")
(add-keybinding "C-c s C-g" "(keyboard-quit)")
(add-keybinding "C-c s l" "(set-left-margin)")
(add-keybinding "C-c s r" "(set-right-margin)")
(add-keybinding "C-c s c" "(set-cell-width)")
(add-keybinding "C-c s w" "(set-screen-width)")
(add-keybinding "C-c s h" "(set-screen-height)")
(add-keybinding "C-c v" "(print-version)")
(add-keybinding "C-c x" "(prefix)")
(add-keybinding "C-c x C-g" "(keyboard-quit)")
(add-keybinding "C-c x ?" "(llpr \"One of c g s t\")")
(add-keybinding "C-c x c" "(edit-c)")
(add-keybinding "C-c x g" "(edit-guile)")
(add-keybinding "C-c x s" "(edit-siod)")
(add-keybinding "C-c x t" "(edit-tcl)")
(add-keybinding "C-c ?" "(prefix)")
(add-keybinding "C-c ? ?" "(llpr \"One of m s c p\")")
(add-keybinding "C-c C-g" "(keyboard-quit)")
(add-keybinding "C-c ? m" "(show-margins)")
(add-keybinding "C-c ? s" "(show-screen-size)")
(add-keybinding "C-c ? c" "(show-cell-width)")
(add-keybinding "C-c ? p" "(show-pool-info)")
(add-keybinding "C-h" "(prefix)")
(add-keybinding "C-h C-g" "(keyboard-quit)")
(add-keybinding "C-h a" "(command-apropos)")
(add-keybinding "C-h b" "(describe-bindings)")
(add-keybinding "C-h c" "(describe-key-briefly)")
(add-keybinding "C-h C-c" "(help-contents)")
(add-keybinding "C-h f" "(describe-function)")
(add-keybinding "C-h k" "(describe-key)")
(add-keybinding "C-h v" "(print-version)")
(add-keybinding "C-h w" "(where-is)")
(add-keybinding "C-h C-h" "(help-for-help)")
(add-keybinding "C-h ?" "(llpr \"One of a b C-c c f k v w C-h\")")
(add-keybinding "RET" "(hyperlink)")

==> siag_3.1.22.orig.tar.gz: siag-3.1.22/siag/keytable.scm <==
(add-keybinding "SPC" "(set-block)")
(add-keybinding "C-@" "(set-mark-command)")
(add-keybinding "ESC SPC" "(unset-block)")
(add-keybinding "C-a" "(beginning-of-line)")
(add-keybinding "C-b" "(backward-cell)")
(add-keybinding "C-d" "(delete-cell)")
(add-keybinding "C-e" "(end-of-line)")
(add-keybinding "C-f" "(forward-cell)")
(add-keybinding "C-g" "(keyboard-quit)")
(add-keybinding "C-l" "(recenter)")
(add-keybinding "C-n" "(next-line)")
(add-keybinding "C-p" "(previous-line)")
(add-keybinding "C-o" "(insert-line)")
(add-keybinding "C-r" "(search-backward)")
(add-keybinding "C-s" "(search-forward)")
(add-keybinding "C-u" "(universal-argument)")
(add-keybinding "C-v" "(scroll-up)")
(add-keybinding "M-v" "(scroll-down)")
(add-keybinding "ESC v" "(scroll-down)")
(add-keybinding "M-x" "(execute-extended-command)")
(add-keybinding "ESC x" "(execute-extended-command)")
(add-keybinding "?" "(what-cursor-position)")
(add-keybinding "C-x ?" "(what-cursor-position)")
(add-keybinding "!" "(recalc-matrix)")
(add-keybinding "=" "(edit-expression)")
(add-keybinding "\"" "(edit-label)")
(add-keybinding "(" "(execute-extended-command)")
(add-keybinding "<" "(beginning-of-buffer)")
(add-keybinding "M-<" "(beginning-of-buffer)")
(add-keybinding "ESC <" "(beginning-of-buffer)")
(add-keybinding ">" "(end-of-buffer)")
(add-keybinding "M->" "(end-of-buffer)")
(add-keybinding "ESC >" "(end-of-buffer)")
(add-keybinding "ESC" "(prefix)")
(add-keybinding "ESC C-g" "(keyboard-quit)")
(add-keybinding "ESC b" "(scroll-right)")
(add-keybinding "ESC f" "(scroll-left)")
(add-keybinding "ESC g" "(go-to)")
(add-keybinding "ESC p" "(top-of-buffer)")
(add-keybinding "ESC n" "(bottom-of-buffer)")
(add-keybinding "ESC -" "(argument-sign)")
(add-keybinding "ESC 0" "(argument-digit)")
(add-keybinding "ESC 1" "(argument-digit)")
(add-keybinding "ESC 2" "(argument-digit)")
(add-keybinding "ESC 3" "(argument-digit)")
(add-keybinding "ESC 4" "(argument-digit)")
(add-keybinding "ESC 5" "(argument-digit)")
(add-keybinding "ESC 6" "(argument-digit)")
(add-keybinding "ESC 7" "(argument-digit)")
(add-keybinding "ESC 8" "(argument-digit)")
(add-keybinding "ESC 9" "(argument-digit)")
(add-keybinding "C-x" "(prefix)")
(add-keybinding "C-x C-b" "(list-buffers)")
(add-keybinding "C-x C-c" "(quit-program)")
(add-keybinding "C-x C-f" "(load-buffer)")
(add-keybinding "C-x C-g" "(keyboard-quit)")
(add-keybinding "C-x C-s" "(save-buffer)")
(add-keybinding "C-x C-w" "(save-buffer-as)")
(add-keybinding "C-x C-x" "(exchange-point-and-mark)")
(add-keybinding "C-x b" "(switch-to-buffer)")
(add-keybinding "C-x e" "(call-last-kbd-macro)")
(add-keybinding "C-x k" "(kill-buffer 1)")
(add-keybinding "C-x o" "(other-window)")
(add-keybinding "C-x 0" "(delete-window)")
(add-keybinding "C-x 1" "(delete-other-windows)")
(add-keybinding "C-x 2" "(split-window-vertically)")
(add-keybinding "C-x =" "(what-cursor-position)")
(add-keybinding "C-x (" "(start-kbd-macro)")
(add-keybinding "C-x )" "(end-kbd-macro)")
(add-keybinding "C-c" "(prefix)")
(add-keybinding "C-c C-d" "(delete-cell)")
(add-keybinding "C-c C-g" "(keyboard-quit)")
(add-keybinding "C-c !" "(recalc-matrix)")
(add-keybinding "C-c g" "(go-to)")
(add-keybinding "C-c l" "(edit-label)")
(add-keybinding "C-c x" "(edit-expression)")
(add-keybinding "C-c =" "(interpreter-test 'C)")
(add-keybinding "C-c b" "(prefix)")
(add-keybinding "C-c b ?" "(llpr \"One of SPC c d i p s\")")
(add-keybinding "C-c b C-g" "(keyboard-quit)")
(add-keybinding "C-c b SPC" "(set-block)")
(add-keybinding "C-c b c" "(copy-block)")
(add-keybinding "C-c b d" "(delete-block)")
(add-keybinding "C-c b f" "(fill-block)")
(add-keybinding "C-c b i" "(intelligent-copy-block)")
(add-keybinding "C-c b p" "(print-block)")
(add-keybinding "C-c b s" "(save-block-file)")
(add-keybinding "C-c c" "(prefix)")
(add-keybinding "C-c c C-g" "(keyboard-quit)")
(add-keybinding "C-c c ?" "(llpr \"One of g s t\")")
(add-keybinding "C-c c g" "(execute-guile)")
(add-keybinding "C-c c s" "(execute-siod)")
(add-keybinding "C-c c t" "(execute-tcl)")
(add-keybinding "C-c s" "(prefix)")
(add-keybinding "C-c s ?" "(llpr \"One of l r c w h\")")
(add-keybinding "C-c s C-g" "(keyboard-quit)")
(add-keybinding "C-c s l" "(set-left-margin)")
(add-keybinding "C-c s r" "(set-right-margin)")
(add-keybinding "C-c s c" "(set-cell-width)")
(add-keybinding "C-c s w" "(set-screen-width)")
(add-keybinding "C-c s h" "(set-screen-height)")
(add-keybinding "C-c v" "(print-version)")
(add-keybinding "C-c x" "(prefix)")
(add-keybinding "C-c x C-g" "(keyboard-quit)")
(add-keybinding "C-c x ?" "(llpr \"One of c g s t\")")
(add-keybinding "C-c x c" "(edit-c)")
(add-keybinding "C-c x g" "(edit-guile)")
(add-keybinding "C-c x s" "(edit-siod)")
(add-keybinding "C-c x t" "(edit-tcl)")
(add-keybinding "C-c ?" "(prefix)")
(add-keybinding "C-c ? ?" "(llpr \"One of m s c p\")")
(add-keybinding "C-c C-g" "(keyboard-quit)")
(add-keybinding "C-c ? m" "(show-margins)")
(add-keybinding "C-c ? s" "(show-screen-size)")
(add-keybinding "C-c ? c" "(show-cell-width)")
(add-keybinding "C-c ? p" "(show-pool-info)")
(add-keybinding "C-h" "(prefix)")
(add-keybinding "C-h C-g" "(keyboard-quit)")
(add-keybinding "C-h a" "(command-apropos)")
(add-keybinding "C-h b" "(describe-bindings)")
(add-keybinding "C-h c" "(describe-key-briefly)")
(add-keybinding "C-h C-c" "(help-contents)")
(add-keybinding "C-h f" "(describe-function)")
(add-keybinding "C-h k" "(describe-key)")
(add-keybinding "C-h v" "(print-version)")
(add-keybinding "C-h w" "(where-is)")
(add-keybinding "C-h C-h" "(help-for-help)")
(add-keybinding "C-h ?" "(llpr \"One of a b C-c c f k v w C-h\")")
(add-keybinding "RET" "(hyperlink)")
(add-keybinding "C-z" "(suspend-function)")
